timeseries.SpaceCurve.auto_bin — GDA Toolbox v1.0 Manual

# timeseries.SpaceCurve.auto_bin

`SpaceCurve.` `auto_bin`(num_bins=10, underflow=0, overflow=100)

  Count bins on the transformed persistence diagrams of -Speed/7 (so it is expected to be between 0 and 100) -Climb/3 (so it is expected to be between 0 and 100) -Curvature*10000 (so it is expected to be between 0 and 100) -Torsion*10000 (so it is expected to be between 0 and 100) -Bank*100/(pi/4) (==grade, between 0 and 100)

  Bins are added for (-inf, underflow] and (overflow,inf). If underflow and overflow are not provided, they are set to min/max.

#### Previous topic

timeseries.SpaceCurve.arclength_param

#### Next topic

timeseries.SpaceCurve.clean_copy